'' =================================================================================================
''
''   File....... jm_serial_tx_test.spin
''   Purpose....
''   Author..... Jon McPhalen
''               Copyright (c) 2022 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon.mcphalen@gmail.com
''   Started....
''   Updated.... 16 DEC 2022
''
''   {$P1}
''
'' =================================================================================================


con { timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                          ' use 5MHz crystal

  CLK_FREQ = (_clkmode >> 6) * _xinfreq                         ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                   ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                               ' ticks in 1us


con { terminal }

  BR_TERM  = 115_200                                            ' terminal baud rate


con { fixed io pins }

  RX1      = 31  { I }                                          ' serial / programming
  TX1      = 30  { O }

  SDA1     = 29  { I/O }                                        ' i2c / eeprom
  SCL1     = 28  { I/O }


con { app io pins }


con

  #true,  ON, OFF
  #false, NO, YES


obj

' main                                                          ' * master Spin cog
  time : "jm_time_80"                                           '   timing and delays (80MHz)
  prng : "jm_prng"                                              '   pseudo-random number generation
  io   : "jm_io"                                                '   simple io
  term : "jm_serial_tx"                                         ' * serial output for terminal

' * uses cog when loaded


dat { pre-initialized }


var { globals }


pub main | n

  setup

  time.pause(5000)                                              ' time to open PST

  term.tx(term#CLS)

  term.str(string("Testing... "))
  repeat n from 1 to 3
    time.pause(1000)
    term.fxdec(n, 0)
    term.tx(" ")
  term.txn(13, 2)

  repeat n from 0 to 100 step 5
    term.fmt_number(n, 10, 0, 3, " ")
    term.tx(13)

  repeat
    waitcnt(0)


pub setup

'' Setup IO and objects for application

  time.start                                                    ' setup timing & delays

  prng.seed(-cnt, -cnt ~> 2, $CAFE_BABE, cnt <- 2, cnt)         ' seed randomizer

  io.start(0, 0)                                                ' clear all pins (master cog)

  term.start(TX1, BR_TERM)                                      ' start serial for terminal *


con { license }

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}